@@ -7,7 +7,7 @@ use warnings;
 use Carp;	# Import Carp for warnings
 use Config::Abstraction 0.25;
 use Log::Log4perl;
-use Params::Get 0.04;	# Import Params::Get for parameter handling
+use Params::Get 0.05;	# Import Params::Get for parameter handling
 use Readonly::Values::Syslog 0.02;
 use Sys::Syslog;	# Import Sys::Syslog for syslog support
 use Scalar::Util 'blessed';	# Import Scalar::Util for object reference checking
@@ -18,11 +18,11 @@ Log::Abstraction - Logging Abstraction Layer
 
 =head1 VERSION
 
-0.16
+0.17
 
 =cut
 
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 =head1 SYNOPSIS
 
@@ -207,7 +207,8 @@ sub new {
 # $logger->_log($level, @messages);
 # $logger->_log($level, \@messages);
 
-sub _log {
+sub _log
+{
 	my ($self, $level, @messages) = @_;
 
 	if(!UNIVERSAL::isa((caller)[0], __PACKAGE__)) {
@@ -330,6 +331,19 @@ sub level
 	return $self->{'level'};
 }
 
+=head2 messages
+
+Return all the messages emmitted so far
+
+=cut
+
+sub messages
+{
+	my $self = shift;
+
+	return $self->{'messages'};
+}
+
 =head2 debug
 
   $logger->debug(@messages);
